package com.sitemesh;

import java.util.Properties;
import javax.servlet.Config;
import javax.servlet.http.HttpServletRequest;

/**
 * The DecoratorMapper is resposible for determining which
 * {@link com.sitemesh.Decorator} should be used for a
 * {@link com.sitemesh.Page} .
 *
 * Implementations of this are returned by {@link com.sitemesh.Factory} .
 *
 * All implementations of this should be thread safe.
 *
 * @author <a href="mailto:joe@truemesh.com">Joe Walnes</a>
 * @version $Revision: 1.8 $
 */
public interface DecoratorMapper {
	/**
	 * @directed
	 * @label locates
	 */
    /*#Decorator lnkDecorator;*/

	/**
	 * Initialize the mapper. This is always called before the other method.
	 *
	 * @param config Config supplied by Servlet or Filter.
	 * @param properties Any initialization properties (specific to implementation).
	 * @exception java.lang.InstantionException should be thrown if the implementation
	 *            cannot be initialized properly.
	 */
	void init(Config config, Properties properties) throws InstantiationException;

	/**
	 * Return appropriate Decorator for a certain Page.
	 * The implementation can determine the result based on the actual request
	 * or the data of the parsed page.
	 */
	Decorator getDecorator(HttpServletRequest request, Page page);

}
