package com.sitemesh.parser;

import com.sitemesh.HTMLPage;
import java.io.*;
import java.net.MalformedURLException;
import java.net.URL;

/**
 * Abstract implementation of {@link com.sitemesh.HTMLPage}.
 *
 * <p>Adds to {@link com.sitemesh.parser.AbstractPage} some HTML methods.
 * To implement, follow guidelines of super-class, and implement the 2
 * abstract methods states below.</p>
 *
 * @author <a href="joe@truemesh.com">Joe Walnes</a>
 * @version $Revision: 1.5 $
 *
 * @see com.sitemesh.parser.AbstractPage
 * @see com.sitemesh.HTMLPage
 */
public abstract class AbstractHTMLPage extends AbstractPage implements HTMLPage {

	/**
	 * Write data of html <code>&lt;head&gt;</code> tag.
	 *
	 * <p>Must be implemented. Data written should not actually contain the
	 * head tags, but all the data in between.
	 */
	public abstract void writeHead( Writer out ) throws IOException;

	/**
	 * Write data of html <code>&lt;body&gt;</code> tag.
	 *
	 * <p>Must be implemented. Data written should not actually contain the
	 * body tags, but all the data in between.
	 */
	public abstract void writeBody( Writer out ) throws IOException;

	/**
	 * Calls {@link #writeHead(java.io.Writer)}
	 */
	public void writeHead( OutputStream out ) throws IOException {
		writeHead( new OutputStreamWriter( out ) );
	}

	/**
	 * Calls {@link #writeBody(java.io.Writer)}
	 */
	public void writeBody( OutputStream out ) throws IOException {
		writeBody( new OutputStreamWriter( out ) );
	}

	/**
	 * Return title of from "title" property. Never returns null.
	 */
	public String getTitle() {
		return noNull(getProperty( "title" ));
	}

	/**
	 * Return decorator name of from "decorator" property. Never returns null.
	 */
	public String getDecoratorName() {
		return noNull(getProperty( "decorator" ));
	}

}
